==================
Citing :mod:`unyt`
==================

If you make use of unyt in work that leads to a publication we would appreciate
a mention in the text of the paper or in the acknowledgements along with a
citation to our `paper
<https://joss.theoj.org/papers/dbc27acb614dd33eb02b029ef20e7fe7>`_ in the
Journal of Open Source Software. You can use the following BibTeX::

 @article{Goldbaum2018,
   doi = {10.21105/joss.00809},
   url = {https://doi.org/10.21105/joss.00809},
   year  = {2018},
   month = {aug},
   publisher = {The Open Journal},
   volume = {3},
   number = {28},
   pages = {809},
   author = {Nathan J. Goldbaum and John A. ZuHone and Matthew J. Turk and Kacper Kowalik and Anna L. Rosen},
   title = {unyt: Handle,  manipulate,  and convert data with units in Python},
   journal = {Journal of Open Source Software}
 }

Or the following citation format:

  Goldbaum et al., (2018). unyt: Handle, manipulate, and convert data with units in Python . Journal of Open Source Software, 3(28), 809, https://doi.org/10.21105/joss.00809
